==> metalint-0.5.2.tgz: package/lib/wrapper/markdownlint.js <==
"use strict";

const markdownlint = require("markdownlint");
const SEVERITY     = require("../severity");

/**
 * Vérifier du code source avec le linter <strong>MardownLint</strong>.
 *
 * @param {string} source  Le code source qui sera vérifié.
 * @param {Object} options Les options qui seront passées au linter.
 * @param {number} level   Le niveau de sévérité minimum des notifications
 *                         retournées.
 * @return {Promise.<Array.<Object>>} Une promesse retournant la liste des
 *                                    notifications.
 */
const wrapper = function (source, options, level) {
    if (SEVERITY.ERROR > level) {
        return Promise.resolve([]);
    }

    return new Promise(function (resolve) {
        const config = {
            "strings": { source },
            "config":  options
        };
        markdownlint(config, function (_, results) {
            // Ignorer les erreurs car la validation d'une chaine de caractères
            // ne remonte pas d'erreur.
            if (0 === Object.keys(results.source).length) {
                resolve([]);
            } else {
                const notices = [];
                for (const result of results.toString().split("\n")) {
                    const parts = result.match(/[^ ]+ ([0-9]+): ([^ ]+) (.*)/);
                    notices.push({
                        "linter":    "markdownlint",
                        "rule":      parts[2],
                        "severity":  SEVERITY.ERROR,
                        "message":   parts[3],
                        "locations": [{ "line": parseInt(parts[1], 10) }]
                    });
                }
                resolve(notices);
            }
        });
    });
}; // wrapper()

module.exports = wrapper;

==> metalint-0.7.1.tgz: package/lib/wrapper/markdownlint.js <==
"use strict";

const markdownlint = require("markdownlint");
const SEVERITY     = require("../severity");

/**
 * Vérifier un fichier avec le linter <strong>MardownLint</strong>.
 *
 * @param {string} file    Le fichier qui sera vérifié.
 * @param {Object} options Les options qui seront passées au linter.
 * @param {number} level   Le niveau de sévérité minimum des notifications
 *                         retournées.
 * @return {Promise.<Array.<Object>>} Une promesse retournant la liste des
 *                                    notifications.
 */
const wrapper = function (file, options, level) {
    if (SEVERITY.ERROR > level) {
        return Promise.resolve([]);
    }

    return new Promise(function (resolve) {
        const config = {
            "files":  file,
            "config": options
        };
        markdownlint(config, function (_, results) {
            if ("" === results.toString()) {
                resolve([]);
            } else {
                const notices = [];
                for (const result of results.toString().split("\n")) {
                    const parts = result.match(/[^ ]+ ([0-9]+): ([^ ]+) (.*)/);
                    notices.push({
                        "linter":    "markdownlint",
                        "rule":      parts[2],
                        "severity":  SEVERITY.ERROR,
                        "message":   parts[3],
                        "locations": [{ "line": parseInt(parts[1], 10) }]
                    });
                }
                resolve(notices);
            }
        });
    });
}; // wrapper()

module.exports = wrapper;
